@@ -1,7 +1,6 @@
-from .views import send, verify
+from .views import verify
 from django.urls import path
 
 urlpatterns = [
-    path('', send),
     path('<str:email>/<str:email_token>', verify)
 ]
